@@ -191,6 +191,15 @@ void csminwel(double (*fcn)(double *x, int n, double **args, int *dims),
    retcode[2] = 101;
    /* iterate until done is false */
    while (!done) {
+#ifdef OCTAVE_MEX_FILE
+     OCTAVE_QUIT;
+#elif defined(MATLAB_MEX_FILE)
+     if (utIsInterruptPending())
+       {
+         mexPrintf("\n\n** Ctrl-C detected, quitting...\n");
+         dw_exit(0);
+       }
+#endif
       #ifdef VERBOSE_DETOUTPUT
       time(&begtime);
       #endif
@@ -373,7 +382,7 @@ void csminwel(double (*fcn)(double *x, int n, double **args, int *dims),
       #endif
 
       //--------- Prints outputs to a file. ---------
-      if ( !(fptr_interesults = fopen(filename_sp2vecs,"w")) ) {
+      if ( !(fptr_interesults = fopen(filename_sp2vecs,"wt")) ) {
          printf("\n\nUnable to create the starting point data file %s in csminwel.c!\n", filename_sp2vecs);
          dw_exit(EXIT_FAILURE);
       }
@@ -479,7 +488,7 @@ void csminwel(double (*fcn)(double *x, int n, double **args, int *dims),
 
 
    //--------- Prints outputs to a file. ---------
-   if ( !(fptr_interesults = fopen(filename_sp2vecs,"w")) ) {
+   if ( !(fptr_interesults = fopen(filename_sp2vecs,"wt")) ) {
       printf("\n\nUnable to create the starting point data file %s in csminwel.c!\n", filename_sp2vecs);
       dw_exit(EXIT_FAILURE);
    }
