@@ -209,6 +209,13 @@ switch S(1).type
         else
             Dates = S(1).subs{1};
         end
+        % Test if Dates is out of bounds
+        if min(Dates)<min(A.dates)
+            error(['dseries::subsref: Indices are out of bounds! Subsample cannot start before ' date2string(A.dates(1)) '.'])
+        end
+        if  max(Dates)>max(A.dates)
+            error(['dseries::subsref: Indices are out of bounds! Subsample cannot end after ' date2string(A.dates(end)) '.'])
+        end
         % Extract a subsample using a dates object
         [junk,tdx] = intersect(A.dates.time,Dates.time,'rows');
         B = dseries();
@@ -228,6 +235,7 @@ switch S(1).type
             if size(A.data,2)>1
                 S(1).subs = [S(1).subs, ':'];
             end
+            B = dseries();
             B.data = builtin('subsref', A.data, S(1));
             B.nobs = size(B.data,1);
             B.vobs = A.vobs;
@@ -637,4 +645,57 @@ end
 %$ end
 %$
 %$ T = all(t);
-%@eof:14
\ No newline at end of file
+%@eof:14
+
+%@test:15
+%$ try
+%$     ds = dseries(transpose(1:5));
+%$     ts = ds(2:3);
+%$     t(1) = 1;
+%$ catch
+%$     t(1) = 0;
+%$ end
+%$
+%$ if t(1)>1
+%$     t(2) = isdseries(ts);
+%$     t(3) = isequal(ts.data,ds.data(2:3));
+%$ end
+%$
+%$ T = all(t);
+%@eof:15
+
+%@test:16
+%$ try
+%$     ds = dseries(transpose(1:5));
+%$     ts = ds(2:6);
+%$     t(1) = 0;
+%$ catch
+%$     t(1) = 1;
+%$ end
+%$
+%$ T = all(t);
+%@eof:16
+
+%@test:17
+%$ try
+%$     ds = dseries(transpose(1:5));
+%$     ts = ds(dates('1Y'):dates('6Y'));
+%$     t(1) = 0;
+%$ catch
+%$     t(1) = 1;
+%$ end
+%$
+%$ T = all(t);
+%@eof:17
+
+%@test:18
+%$ try
+%$     ds = dseries(transpose(1:5));
+%$     ts = ds(dates('-2Y'):dates('4Y'));
+%$     t(1) = 0;
+%$ catch
+%$     t(1) = 1;
+%$ end
+%$
+%$ T = all(t);
+%@eof:18
\ No newline at end of file
