@@ -1,4 +1,4 @@
-function DirectoryName = CheckPath(type,dname)
+function [DirectoryName, info] = CheckPath(type,dname)
 % Creates the subfolder "./M_.dname/type" if it does not exist yet.
 %
 % INPUTS
@@ -6,12 +6,13 @@ function DirectoryName = CheckPath(type,dname)
 %    dname  [string]    Name of the directory
 %
 % OUTPUTS
-%    none.
+%    DirectoryName      string, name of the directory (with path).
+%    info               integer scalar, equal to 1 if the routine creates directory dname/type, zero otherwise.
 %
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2005-2011 Dynare Team
+% Copyright (C) 2005-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -28,16 +29,23 @@ function DirectoryName = CheckPath(type,dname)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
+info = 0;
+
 DirectoryName = [ dname '/' type ];
 
 if ~isdir(dname)
     % Make sure there isn't a file with the same name, see trac ticket #47
-    delete(dname)
+    if isfile(dname)
+        delete(dname)
+    end
     mkdir('.', dname);
 end
 
 if ~isdir(DirectoryName)
     % Make sure there isn't a file with the same name, see trac ticket #47
-    delete(DirectoryName)
+    if isfile(DirectoryName)
+        delete(DirectoryName)
+    end
     mkdir('.',DirectoryName);
+    info = 1;
 end
