@@ -183,13 +183,12 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcccc} \n');
-        fprintf(fidTeX,'\\caption{Results from posterior maximization (parameters)}\n ');
+        fprintf(fidTeX,'\\caption{Results from posterior maximization (parameters)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:1}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. & Posterior mode & s.d. \\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
-        fprintf(fidTeX,'\\label{Table:Posterior:1}\\\\\n');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. & Posterior mode & s.d. \\\\ \n');
         fprintf(fidTeX,'\\hline \\endhead \n');
@@ -221,12 +220,12 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcccc} \n');
-        fprintf(fidTeX,'\\caption{Results from posterior maximization (standard deviation of structural shocks)}\n ');
+        fprintf(fidTeX,'\\caption{Results from posterior maximization (standard deviation of structural shocks)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:2}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. & Posterior mode & s.d. \\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:2}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. & Posterior mode & s.d. \\\\ \n');
@@ -260,12 +259,12 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcccc} \n');
-        fprintf(fidTeX,'\\caption{Results from posterior maximization (standard deviation of measurement errors)}\n ');
+        fprintf(fidTeX,'\\caption{Results from posterior maximization (standard deviation of measurement errors)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:3}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. &  Posterior mode & s.d. \\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:3}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. &  Posterior mode & s.d. \\\\ \n');
@@ -299,12 +298,12 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcccc} \n');
-        fprintf(fidTeX,'\\caption{Results from posterior parameters (correlation of structural shocks)}\n ');
+        fprintf(fidTeX,'\\caption{Results from posterior parameters (correlation of structural shocks)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:4}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. &  Posterior mode & s.d. \\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:4}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. &  Posterior mode & s.d. \\\\ \n');
@@ -339,12 +338,12 @@ if any(bayestopt_.pshape > 0) && options_.TeX %% Bayesian estimation (posterior
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcccc} \n');
-        fprintf(fidTeX,'\\caption{Results from posterior parameters (correlation of measurement errors)}\n ');
+        fprintf(fidTeX,'\\caption{Results from posterior parameters (correlation of measurement errors)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:5}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. &  Posterior mode & s.d. \\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,'\\label{Table:Posterior:5}\\\\\n');
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Prior distribution & Prior mean  & Prior s.d. &  Posterior mode & s.d. \\\\ \n');
@@ -380,12 +379,12 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcc} \n');
-        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (parameters)}\n ']);
+        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (parameters)}\\\\\n ']);
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':1}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':1}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
@@ -416,12 +415,12 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcc} \n');
-        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (standard deviation of structural shocks)}\n ']);
+        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (standard deviation of structural shocks)}\\\\\n ']);
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':2}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':2}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
@@ -453,12 +452,12 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcc} \n');
-        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (standard deviation of measurement errors)}\n ']);
+        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (standard deviation of measurement errors)}\\\\\n ']);
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':3}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':3}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
@@ -490,12 +489,12 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcc} \n');
-        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (correlation of structural shocks)}\n ']);
+        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (correlation of structural shocks)}\\\\\n ']);
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':4}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':4}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
@@ -528,12 +527,12 @@ elseif all(bayestopt_.pshape == 0) && options_.TeX %% MLE and GMM Latex output
         fprintf(fidTeX,' \n');
         fprintf(fidTeX,'\\begin{center}\n');
         fprintf(fidTeX,'\\begin{longtable}{l|lcc} \n');
-        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (correlation of measurement errors)}\n ']);
+        fprintf(fidTeX,['\\caption{Results from ' table_title ' maximization (correlation of measurement errors)}\\\\\n ']);
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':5}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
         fprintf(fidTeX,'\\hline \\endfirsthead \n');
-        fprintf(fidTeX,'\\caption{(continued)}\n ');
+        fprintf(fidTeX,'\\caption{(continued)}\\\\\n ');
         fprintf(fidTeX,['\\label{Table:' LaTeXtitle ':5}\\\\\n']);
         fprintf(fidTeX,'\\hline\\hline \\\\ \n');
         fprintf(fidTeX,'  & Mode & s.d. & t-stat\\\\ \n');
