@@ -257,7 +257,7 @@ end
 
 % Return, with endogenous penalty when possible, if dynare_resolve issues an error code (defined in resol).
 if info(1) == 1 || info(1) == 2 || info(1) == 5 || info(1) == 7 || info(1) ...
-            == 8 || info(1) == 22 || info(1) == 24 || info(1) == 19
+            == 8 || info(1) == 22 || info(1) == 24 || info(1) == 19 || info(1) == 25
     fval = objective_function_penalty_base+1;
     info = info(1);
     exit_flag = 0;
