@@ -337,7 +337,7 @@ if iload <=0,
         else
             parameters = 'Random_prior_params';
         end
-    else
+    end
     idehess_point.params=params;
 %     siH = idemodel_point.siH;
 %     siJ = idemoments_point.siJ;
@@ -351,7 +351,6 @@ if iload <=0,
     if ~options_.nograph,
         plot_identification(params,idemoments_point,idehess_point,idemodel_point,idelre_point,advanced,parameters,name,IdentifDirectoryName);
     end
-    end
 
     if SampleSize > 1,
         skipline()
@@ -533,7 +532,7 @@ if SampleSize > 1,
     disp('Testing MC sample')
     disp_identification(pdraws, idemodel, idemoments, name);
     if ~options_.nograph,
-        plot_identification(pdraws,idemoments,idehess_point,idemodel,idelre,advanced,'MC sample - ',name, IdentifDirectoryName);
+        plot_identification(pdraws,idemoments,idehess_point,idemodel,idelre,advanced,'MC sample ',name, IdentifDirectoryName);
     end
     if advanced,
         jcrit=find(idemoments.ino);
