@@ -1,4 +1,4 @@
-function [rmse_MC, ixx] = filt_mc_(OutDir,options_gsa_)
+function [rmse_MC, ixx] = filt_mc_(OutDir,options_gsa_,dataset_)
 % function [rmse_MC, ixx] = filt_mc_(OutDir)
 % inputs (from opt_gsa structure)
 % vvarvecm = options_gsa_.var_rmse;
@@ -16,7 +16,7 @@ function [rmse_MC, ixx] = filt_mc_(OutDir,options_gsa_)
 % Reference:
 % M. Ratto, Global Sensitivity Analysis for Macroeconomic models, MIMEO, 2006.
 
-% Copyright (C) 2012 Dynare Team
+% Copyright (C) 2012-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -50,11 +50,10 @@ fname_ = M_.fname;
 lgy_ = M_.endo_names;
 dr_ = oo_.dr;
 
-disp(' ')
-disp(' ')
+skipline(2)
 disp('Starting sensitivity analysis')
 disp('for the fit of EACH observed series ...')
-disp(' ')
+skipline()
 disp('Deleting old SA figures...')
 a=dir([OutDir,filesep,'*.*']);
 tmp1='0';
@@ -74,11 +73,11 @@ end
 for j=1:length(a),
     if strmatch([fname_,tmp],a(j).name),
         disp(a(j).name)
-        delete([OutDir,'/',a(j).name])
+        delete([OutDir,filesep,a(j).name])
     end,
     if strmatch([fname_,tmp1],a(j).name),
         disp(a(j).name)
-        delete([OutDir,'/',a(j).name])
+        delete([OutDir,filesep,a(j).name])
     end,
 end
 disp('done !')
@@ -114,26 +113,30 @@ end
 if ~loadSA,
     if exist('xparam1','var')
         M_ = set_all_parameters(xparam1,estim_params_,M_);
-        steady_(M_,options_,oo_);
-        ys_mode=oo_.steady_state;
+        ys_mode=steady_(M_,options_,oo_);
     end
     if exist('xparam1_mean','var')
         M_ = set_all_parameters(xparam1_mean,estim_params_,M_);
-        steady_(M_,options_,oo_);
-        ys_mean=oo_.steady_state;
+        ys_mean=steady_(M_,options_,oo_);
     end
     %   eval(options_.datafile)
-    obs = dat_fil_(options_.datafile);
+    Y = dataset_.data;
+    gend = dataset_.info.ntobs;
+    data_index = dataset_.missing.aindex;
+    missing_value = dataset_.missing.state;
+    for jx=1:gend, data_indx(jx,data_index{jx})=true; end
     %stock_gend=data_info.gend;
     %stock_data = data_info.data;
-    load([DirectoryName '/' M_.fname '_data.mat']);    
+    load([DirectoryName filesep M_.fname '_data.mat']);    
     filfilt = dir([DirectoryName filesep M_.fname '_filter_step_ahead*.mat']);
+    filsmooth = dir([DirectoryName filesep M_.fname '_smooth*.mat']);
+    filupdate = dir([DirectoryName filesep M_.fname '_update*.mat']);
     filparam = dir([DirectoryName filesep M_.fname '_param*.mat']);
     x=[];
     logpo2=[];
     sto_ys=[];
     for j=1:length(filparam),
-        %load([DirectoryName '/' M_.fname '_param',int2str(j),'.mat']);
+        %load([DirectoryName filesep M_.fname '_param',int2str(j),'.mat']);
         if isempty(strmatch([M_.fname '_param_irf'],filparam(j).name))
             load([DirectoryName filesep filparam(j).name]);
             x=[x; stock];
@@ -145,60 +148,57 @@ if ~loadSA,
     nruns=size(x,1);
     nfilt=floor(pfilt*nruns);
     if options_.opt_gsa.ppost || (options_.opt_gsa.ppost==0 && options_.opt_gsa.lik_only==0)
-        disp(' ')
+        skipline()
         disp('Computing RMSE''s...')
         fobs = options_.first_obs;
         nobs=options_.nobs;
         for i=1:size(vvarvecm,1),
             vj=deblank(vvarvecm(i,:));
-            eval(['vobs =obs.',vj,'(fobs:fobs-1+nobs);'])
-            if options_.prefilter == 1
-                %eval([vj,'=',vj,'-bayestopt_.mean_varobs(i);'])
-                %eval([vj,'=',vj,'-mean(',vj,',1);'])
-                vobs = vobs-mean(vobs,1);
-            end
             
-            jxj = strmatch(vj,lgy_(dr_.order_var,:),'exact');
-            js = strmatch(vj,lgy_,'exact');
+            jxj(i) = strmatch(vj,lgy_(dr_.order_var,:),'exact');
+            js(i) = strmatch(vj,lgy_,'exact');
+            yss(i,:,:)=repmat(sto_ys(:,js(i))',[nobs,1]);
+        end
             if exist('xparam1','var')
-                %       if isfield(oo_,'FilteredVariables')
-                %       eval(['rmse_mode(i) = sqrt(mean((vobs(istart:end)-oo_.steady_state(js)-oo_.FilteredVariables.',vj,'(istart:end-1)).^2));'])
-                %       else
-                [alphahat,etahat,epsilonhat,ahat,SteadyState,trend_coeff,aK] = DsgeSmoother(xparam1,stock_gend,stock_data,{},0);
-                y0 = squeeze(aK(1,jxj,:)) + ...
-                    kron(ys_mode(js,:),ones(size(aK,3),1));
-                %       y0 = ahat(jxj,:)' + ...
-                %         kron(ys_mode(js,:),ones(size(ahat,2),1));
-                rmse_mode(i) = sqrt(mean((vobs(istart:end)-y0(istart:end-1)).^2));
-                %       end
+                [alphahat,etahat,epsilonhat,ahat,SteadyState,trend_coeff,aK] = DsgeSmoother(xparam1,gend,Y,data_index,missing_value);
+                y0 = transpose( squeeze(aK(1,jxj,1:gend)));% + kron(ys_mode(js),ones(1,gend)));
+                yobs = transpose( ahat(jxj,:));% + kron(ys_mode(js),ones(1,gend)));
+                rmse_mode = sqrt(mean((yobs(istart:end,:)-y0(istart:end,:)).^2));
+                r2_mode = 1-sum((yobs(istart:end,:)-y0(istart:end,:)).^2)./sum(yobs(istart:end,:).^2);
             end
-            y0=zeros(nobs+1,nruns);
+            y0=yss*0;
             nbb=0;
             for j=1:length(filfilt),
                 load([DirectoryName filesep M_.fname '_filter_step_ahead',num2str(j),'.mat']);
                 nb = size(stock,4);
-                %         y0(:,nbb+1:nbb+nb)=squeeze(stock(1,js,:,:)) + ...
-                %           kron(sto_ys(nbb+1:nbb+nb,js)',ones(size(stock,3),1));
-                y0(:,nbb+1:nbb+nb)=squeeze(stock(1,js,1:nobs+1,:)) + ...
-                    kron(sto_ys(nbb+1:nbb+nb,js)',ones(nobs+1,1));
-                %y0(:,:,size(y0,3):size(y0,3)+size(stock,3))=stock;
+                y0(:,:,nbb+1:nbb+nb)=y0(:,:,nbb+1:nbb+nb)+squeeze(stock(1,js,1:nobs,:));
+                nbb=nbb+nb;
+                clear stock;
+            end
+            yobs=-yss;
+            nbb=0;
+            for j=1:length(filupdate),
+                load([DirectoryName filesep M_.fname '_update',num2str(j),'.mat']);
+                nb = size(stock,3);
+                yobs(:,:,nbb+1:nbb+nb)=yobs(:,:,nbb+1:nbb+nb)+squeeze(stock(js,1:nobs,:));
                 nbb=nbb+nb;
                 clear stock;
             end
             y0M=mean(y0,2);
+            rmse_MC=zeros(nruns,length(js));
+            r2_MC=zeros(nruns,length(js));
             for j=1:nruns,
-                rmse_MC(j,i) = sqrt(mean((vobs(istart:end)-y0(istart:end-1,j)).^2));
+                rmse_MC(j,:) = sqrt(mean((yobs(:,istart:end,j)'-y0(:,istart:end,j)').^2));
+                r2_MC(j,:) = 1-mean((yobs(:,istart:end,j)'-y0(:,istart:end,j)').^2)./mean((yobs(:,istart:end,j)').^2);
             end
             if exist('xparam1_mean','var')
                 %eval(['rmse_pmean(i) = sqrt(mean((',vj,'(fobs-1+istart:fobs-1+nobs)-y0M(istart:end-1)).^2));'])
-                [alphahat,etahat,epsilonhat,ahat,SteadyState,trend_coeff,aK] = DsgeSmoother(xparam1_mean,stock_gend,stock_data,{},0);
-                y0 = squeeze(aK(1,jxj,:)) + ...
-                    kron(ys_mean(js,:),ones(size(aK,3),1));
-                %       y0 = ahat(jxj,:)' + ...
-                %         kron(ys_mean(js,:),ones(size(ahat,2),1));
-                rmse_pmean(i) = sqrt(mean((vobs(istart:end)-y0(istart:end-1)).^2));
+                [alphahat,etahat,epsilonhat,ahat,SteadyState,trend_coeff,aK] = DsgeSmoother(xparam1_mean,gend,Y,data_index,missing_value);
+                y0 = transpose( squeeze(aK(1,jxj,1:gend)));% + kron(ys_mean(js),ones(1,gend)));
+                yobs = transpose( ahat(jxj,:));% + kron(ys_mean(js),ones(1,gend)));
+                rmse_pmean = sqrt(mean((yobs(istart:end,:)-y0(istart:end,:)).^2));
+                r2_pmean = 1-mean((yobs(istart:end,:)-y0(istart:end,:)).^2)./mean(yobs(istart:end,:).^2);
             end
-        end
         clear stock_filter;
     end
     for j=1:nruns,
@@ -208,17 +208,17 @@ if ~loadSA,
     disp('... done!')
     
     if options_.opt_gsa.ppost
-        save([OutDir,filesep,fnamtmp,'.mat'], 'x', 'logpo2', 'likelihood', 'rmse_MC', 'rmse_mode','rmse_pmean')
+        save([OutDir,filesep,fnamtmp,'.mat'], 'x', 'logpo2', 'likelihood', 'rmse_MC', 'rmse_mode','rmse_pmean', 'r2_MC', 'r2_mode','r2_pmean')
     else
         if options_.opt_gsa.lik_only
             save([OutDir,filesep,fnamtmp, '.mat'], 'x', 'logpo2','likelihood', '-append')
         else
-            save([OutDir,filesep,fnamtmp, '.mat'], 'x', 'logpo2','likelihood', 'rmse_MC','-append')
+            save([OutDir,filesep,fnamtmp, '.mat'], 'x', 'logpo2','likelihood', 'rmse_MC', 'r2_MC','-append')
             if exist('xparam1_mean','var')
-                save([OutDir,filesep,fnamtmp, '.mat'], 'rmse_pmean','-append')
+                save([OutDir,filesep,fnamtmp, '.mat'], 'rmse_pmean', 'r2_pmean','-append')
             end
             if exist('xparam1','var')
-                save([OutDir,filesep,fnamtmp,'.mat'], 'rmse_mode','-append')
+                save([OutDir,filesep,fnamtmp,'.mat'], 'rmse_mode', 'r2_mode','-append')
             end
         end
     end
@@ -226,7 +226,7 @@ else
     if options_.opt_gsa.lik_only && options_.opt_gsa.ppost==0
         load([OutDir,filesep,fnamtmp, '.mat'],'x','logpo2','likelihood');
     else
-        load([OutDir,filesep,fnamtmp, '.mat'],'x','logpo2','likelihood','rmse_MC','rmse_mode','rmse_pmean');
+        load([OutDir,filesep,fnamtmp, '.mat'],'x','logpo2','likelihood','rmse_MC','rmse_mode','rmse_pmean', 'r2_MC', 'r2_mode','r2_pmean');
     end
     lnprior=logpo2(:)-likelihood(:);
     nruns=size(x,1);
@@ -260,16 +260,20 @@ else
         if options_.opt_gsa.ppost,
             %nfilt0(i)=length(find(rmse_MC(:,i)<rmse_pmean(i)));
             rmse_txt=rmse_pmean;
+            r2_txt=r2_pmean;
         else
             if options_.opt_gsa.pprior || ~exist('rmse_pmean'),
                 if exist('rmse_mode'),
                     rmse_txt=rmse_mode;
+                    r2_txt=r2_mode;
                 else
                     rmse_txt=NaN(1,size(rmse_MC,2));
+                    r2_txt=NaN(1,size(r2_MC,2));
                 end
             else
                 %nfilt0(i)=length(find(rmse_MC(:,i)<rmse_pmean(i)));
                 rmse_txt=rmse_pmean;
+                r2_txt=r2_pmean;
             end
         end
         for j=1:npar+nshock,
@@ -289,9 +293,18 @@ else
     if ~options_.nograph,
     ifig=0;
     for i=1:size(vvarvecm,1),
+        if options_.opt_gsa.ppost
+            temp_name='RMSE Posterior: Log Prior';
+        else
+            if options_.opt_gsa.pprior
+                temp_name='RMSE Prior: Log Prior';
+            else
+                temp_name='RMSE MC: Log Prior';
+            end
+        end
         if mod(i,9)==1,
             ifig=ifig+1;
-            hh=dyn_figure(options_,'name',['Prior ',int2str(ifig)]);
+            hh=dyn_figure(options_,'name',[temp_name,' ',int2str(ifig)]);
         end
         subplot(3,3,i-9*(ifig-1))
         h=cumplot(lnprior(ixx(1:nfilt0(i),i)));
@@ -302,21 +315,30 @@ else
         title(vvarvecm(i,:),'interpreter','none')
         if mod(i,9)==0 || i==size(vvarvecm,1)
             if options_.opt_gsa.ppost
-                dyn_saveas(hh,[OutDir '/' fname_ '_rmse_post_lnprior',int2str(ifig)],options_);
+                dyn_saveas(hh,[OutDir filesep fname_ '_rmse_post_lnprior',int2str(ifig)],options_);
             else
                 if options_.opt_gsa.pprior
-                    dyn_saveas(hh,[OutDir '/' fname_ '_rmse_prior_lnprior',int2str(ifig) ],options_);
+                    dyn_saveas(hh,[OutDir filesep fname_ '_rmse_prior_lnprior',int2str(ifig) ],options_);
                 else
-                    dyn_saveas(hh,[OutDir '/' fname_ '_rmse_mc_lnprior',int2str(ifig) ],options_);
+                    dyn_saveas(hh,[OutDir filesep fname_ '_rmse_mc_lnprior',int2str(ifig) ],options_);
                 end
             end
         end
     end
     ifig=0;
     for i=1:size(vvarvecm,1),
+        if options_.opt_gsa.ppost
+            temp_name='RMSE Posterior: Log Likelihood';
+        else
+            if options_.opt_gsa.pprior
+                temp_name='RMSE Prior: Log Likelihood';
+            else
+                temp_name='RMSE MC: Log Likelihood';
+            end
+        end
         if mod(i,9)==1,
             ifig=ifig+1;
-            hh = dyn_figure(options_,'Name',['Likelihood ',int2str(ifig)]);
+            hh = dyn_figure(options_,'Name',[temp_name,' ',int2str(ifig)]);
         end
         subplot(3,3,i-9*(ifig-1))
         h=cumplot(likelihood(ixx(1:nfilt0(i),i)));
@@ -330,21 +352,30 @@ else
         end
         if mod(i,9)==0 || i==size(vvarvecm,1)
             if options_.opt_gsa.ppost
-                dyn_saveas(hh,[OutDir '/' fname_ '_rmse_post_lnlik',int2str(ifig) ],options_);
+                dyn_saveas(hh,[OutDir filesep fname_ '_rmse_post_lnlik',int2str(ifig) ],options_);
             else
                 if options_.opt_gsa.pprior
-                    dyn_saveas(hh,[OutDir '/' fname_ '_rmse_prior_lnlik',int2str(ifig)],options_);
+                    dyn_saveas(hh,[OutDir filesep fname_ '_rmse_prior_lnlik',int2str(ifig)],options_);
                 else
-                    dyn_saveas(hh,[OutDir '/' fname_ '_rmse_mc_lnlik',int2str(ifig) ],options_);
+                    dyn_saveas(hh,[OutDir filesep fname_ '_rmse_mc_lnlik',int2str(ifig) ],options_);
                 end
             end
         end
     end
     ifig=0;
     for i=1:size(vvarvecm,1),
+        if options_.opt_gsa.ppost
+            temp_name='RMSE Posterior: Log Posterior';
+        else
+            if options_.opt_gsa.pprior
+                temp_name='RMSE Prior: Log Posterior';
+            else
+                temp_name='RMSE MC: Log Posterior';
+            end
+        end
         if mod(i,9)==1,
             ifig=ifig+1;
-            hh = dyn_figure(options_,'Name',['Posterior ',int2str(ifig)]);
+            hh = dyn_figure(options_,'Name',[temp_name,' ',int2str(ifig)]);
         end
         subplot(3,3,i-9*(ifig-1))
         h=cumplot(logpo2(ixx(1:nfilt0(i),i)));
@@ -358,12 +389,12 @@ else
         end
         if mod(i,9)==0 || i==size(vvarvecm,1)
             if options_.opt_gsa.ppost
-                dyn_saveas(hh,[OutDir '/' fname_ '_rmse_post_lnpost',int2str(ifig) ],options_);
+                dyn_saveas(hh,[OutDir filesep fname_ '_rmse_post_lnpost',int2str(ifig) ],options_);
             else
                 if options_.opt_gsa.pprior
-                    dyn_saveas(hh,[OutDir '/' fname_ '_rmse_prior_lnpost',int2str(ifig)],options_);
+                    dyn_saveas(hh,[OutDir filesep fname_ '_rmse_prior_lnpost',int2str(ifig)],options_);
                 else
-                    dyn_saveas(hh,[OutDir '/' fname_ '_rmse_mc_lnpost',int2str(ifig)],options_);
+                    dyn_saveas(hh,[OutDir filesep fname_ '_rmse_mc_lnpost',int2str(ifig)],options_);
                 end
             end
         end
@@ -376,7 +407,7 @@ else
     end
     param_names=param_names(2:end,:);
     
-    disp(' ')
+    skipline()
     disp('RMSE over the MC sample:')
     disp('            min yr RMSE    max yr RMSE')
     for j=1:size(vvarvecm,1),
@@ -384,8 +415,7 @@ else
     end
     invar = find( std(rmse_MC)./mean(rmse_MC)<=0.0001 );
     if ~isempty(invar)
-        disp(' ')
-        disp(' ')
+        skipline(2)
         disp('RMSE is not varying significantly over the MC sample for the following variables:')
         disp(vvarvecm(invar,:))
         disp('These variables are excluded from SA')
@@ -395,7 +425,7 @@ else
     vvarvecm=vvarvecm(ivar,:);
     rmse_MC=rmse_MC(:,ivar);
     
-    disp(' ')
+    skipline()
     % if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior,
     disp(['Sample filtered the ',num2str(pfilt*100),'% best RMSE''s for each observed series ...' ])
     % else
@@ -405,8 +435,7 @@ else
     % set(gca,'xticklabel',vvarvecm)
     % saveas(gcf,[fname_,'_SA_RMSE'])
     
-    disp(' ')
-    disp(' ')
+    skipline(2)
     disp('RMSE ranges after filtering:')
     if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior,
         disp(['             best ',num2str(pfilt*100),'% filtered             remaining 90%'])
@@ -427,6 +456,37 @@ else
         %         max(logpo2(ixx(nfilt+1:end,j)))])])
     end
     
+    %%%%% R2 table
+    
+    skipline()
+    disp('R2 over the MC sample:')
+    disp('            min yr R2      max yr R2')
+    for j=1:size(vvarvecm,1),
+        disp([vvarvecm(j,:), sprintf('%15.5g',[(min(r2_MC(:,j))) [(max(r2_MC(:,j)))]])])
+    end
+    r2_MC=r2_MC(:,ivar);
+    
+    skipline()
+    disp(['Sample filtered the ',num2str(pfilt*100),'% best R2''s for each observed series ...' ])
+    
+    skipline()
+    disp('R2 ranges after filtering:')
+    if options_.opt_gsa.ppost==0 && options_.opt_gsa.pprior,
+        disp(['             best ',num2str(pfilt*100),'% filtered             remaining 90%'])
+        disp(['             min            max            min            max            posterior mode'])
+    else
+        disp(['             best  filtered             remaining '])
+        disp(['             min            max            min            max            posterior mean'])
+    end
+    for j=1:size(vvarvecm,1),
+        disp([vvarvecm(j,:), sprintf('%15.5g',[min(r2_MC(ixx(1:nfilt0(j),j),j)) ...
+            max(r2_MC(ixx(1:nfilt0(j),j),j))  ...
+            min(r2_MC(ixx(nfilt0(j)+1:end,j),j)) ...
+            max(r2_MC(ixx(nfilt0(j)+1:end,j),j)) ...
+            r2_txt(j)])])
+    end
+    
+    %%%%  R2 table
     SP=zeros(npar+nshock,size(vvarvecm,1));
     for j=1:size(vvarvecm,1),
         ns=find(PP(:,j)<alpha);
@@ -447,14 +507,13 @@ else
     % snam=bayestopt_.name(find(nsp>0));
     nsnam=(find(nsp>1));
     
-    disp(' ')
-    disp(' ')
+    skipline(2)
     disp('These parameters do not affect significantly the fit of ANY observed series:')
     disp(snam0)
-    disp(' ')
+    skipline()
     disp('These parameters affect ONE single observed series:')
     disp(snam1)
-    disp(' ')
+    skipline()
     disp('These parameters affect MORE THAN ONE observed series: trade off exists!')
     disp(snam2)
     
@@ -465,8 +524,17 @@ else
     % plot trade-offs
     if ~options_.nograph
     a00=jet(size(vvarvecm,1));
+    if options_.opt_gsa.ppost
+        temp_name='RMSE Posterior Tradeoffs:';
+    else
+        if options_.opt_gsa.pprior
+            temp_name='RMSE Prior Tradeoffs:';
+        else
+            temp_name='RMSE MC Tradeoffs;';
+        end
+    end
     for ix=1:ceil(length(nsnam)/5),
-        hh = dyn_figure(options_);
+        hh = dyn_figure(options_,'name',[temp_name,' observed variables ',int2str(ix)]);
         for j=1+5*(ix-1):min(size(snam2,1),5*ix),
             subplot(2,3,j-5*(ix-1))
             %h0=cumplot(x(:,nsnam(j)+nshock));
@@ -497,7 +565,7 @@ else
             title([pnam{nsnam(j)}],'interpreter','none')
         end
         %subplot(3,2,6)
-        if exist('OCTAVE_VERSION'),
+        if isoctave
             legend(char('base',vvarvecm),'location','eastoutside');
         else
             h0=legend(char('base',vvarvecm),0);
@@ -506,12 +574,12 @@ else
         %h0=legend({'base',vnam{np}}',0);
         %set(findobj(get(h0,'children'),'type','text'),'interpreter','none')
         if options_.opt_gsa.ppost
-            dyn_saveas(hh,[ OutDir '/' fname_ '_rmse_post_' int2str(ix)],options_);
+            dyn_saveas(hh,[ OutDir filesep fname_ '_rmse_post_' int2str(ix)],options_);
         else
             if options_.opt_gsa.pprior
-                dyn_saveas(hh,[OutDir '/' fname_ '_rmse_prior_' int2str(ix) ],options_);
+                dyn_saveas(hh,[OutDir filesep fname_ '_rmse_prior_' int2str(ix) ],options_);
             else
-                dyn_saveas(hh,[OutDir '/' fname_ '_rmse_mc_' int2str(ix)],options_);
+                dyn_saveas(hh,[OutDir filesep fname_ '_rmse_mc_' int2str(ix)],options_);
             end
         end
     end
@@ -521,8 +589,7 @@ else
         nsx(j)=length(find(SP(:,j)));
     end
     
-    disp(' ')
-    disp(' ')
+    skipline(2)
     disp('Sensitivity table (significance and direction):')
     vav=char(zeros(1, size(param_names,2)+3 ));
     ibl = 12-size(vvarvecm,2);
@@ -537,8 +604,7 @@ else
     end
     
     
-    disp(' ')
-    disp(' ')
+    skipline()
     disp('Starting bivariate analysis:')
     
     for i=1:size(vvarvecm,1)
@@ -551,7 +617,7 @@ else
                 fnam = ['rmse_mc_',deblank(vvarvecm(i,:))];
             end
         end
-        stab_map_2(x(ixx(1:nfilt0(i),i),:),alpha2,pvalue,fnam, OutDir);
+        stab_map_2(x(ixx(1:nfilt0(i),i),:),alpha2,pvalue,fnam, OutDir,[],[temp_name ' observed variable ' deblank(vvarvecm(i,:))]);
         
         %     [pc,latent,explained] = pcacov(c0);
         %     %figure, bar([explained cumsum(explained)])
