@@ -38,7 +38,7 @@ function x0 = stab_map_(OutputDirectoryName,opt_gsa)
 % Reference:
 % M. Ratto, Global Sensitivity Analysis for Macroeconomic models, MIMEO, 2006.
 
-% Copyright (C) 2012 Dynare Team
+% Copyright (C) 2012-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -76,9 +76,9 @@ ntra   = opt_gsa.morris_ntra;
 dr_ = oo_.dr;
 %if isfield(dr_,'ghx'),
 ys_ = oo_.dr.ys;
-nspred = dr_.nspred; %size(dr_.ghx,2);
-nboth = dr_.nboth;
-nfwrd = dr_.nfwrd;
+nspred = M_.nspred; %size(dr_.ghx,2);
+nboth = M_.nboth;
+nfwrd = M_.nfwrd;
 %end
 fname_ = M_.fname;
 
@@ -257,13 +257,17 @@ if fload==0,
         %try stoch_simul([]);
         try
             [Tt,Rr,SteadyState,info,M_,options_,oo_] = dynare_resolve(M_,options_,oo_,'restrict');
+            if info(1)==0,
+                info=endogenous_prior_restrictions(Tt,Rr,M_,options_,oo_);
+            end
             infox(j,1)=info(1);
             if infox(j,1)==0 && ~exist('T'),
                 dr_=oo_.dr;
                 if prepSA,
                     try
                         T=zeros(size(dr_.ghx,1),size(dr_.ghx,2)+size(dr_.ghu,2),Nsam);
-                    catch ME
+                    catch
+                        ME = lasterror();
                         if strcmp('MATLAB:nomem',ME.identifier),
                             prepSA=0;
                             disp('The model is too large for storing state space matrices ...')
@@ -388,31 +392,31 @@ if fload==0,
     bkpprior.p4=bayestopt_.p4;
     if pprior,
         if ~prepSA
-            save([OutputDirectoryName '/' fname_ '_prior.mat'], ...
+            save([OutputDirectoryName filesep fname_ '_prior.mat'], ...
                 'bkpprior','lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
                 'egg','yys','nspred','nboth','nfwrd','infox')
         else
-            save([OutputDirectoryName '/' fname_ '_prior.mat'], ...
+            save([OutputDirectoryName filesep fname_ '_prior.mat'], ...
                 'bkpprior','lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
                 'egg','yys','T','nspred','nboth','nfwrd','infox')
         end
 
     else
         if ~prepSA
-            save([OutputDirectoryName '/' fname_ '_mc.mat'], ...
+            save([OutputDirectoryName filesep fname_ '_mc.mat'], ...
                 'lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
                 'egg','yys','nspred','nboth','nfwrd','infox')
         else
-            save([OutputDirectoryName '/' fname_ '_mc.mat'], ...
+            save([OutputDirectoryName filesep fname_ '_mc.mat'], ...
                 'lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
                 'egg','yys','T','nspred','nboth','nfwrd','infox')
         end
     end
 else
     if pprior,
-        filetoload=[OutputDirectoryName '/' fname_ '_prior.mat'];
+        filetoload=[OutputDirectoryName filesep fname_ '_prior.mat'];
     else
-        filetoload=[OutputDirectoryName '/' fname_ '_mc.mat'];
+        filetoload=[OutputDirectoryName filesep fname_ '_mc.mat'];
     end
     load(filetoload,'lpmat','lpmat0','iunstable','istable','iindeterm','iwrong','egg','yys','nspred','nboth','nfwrd','infox')
     Nsam = size(lpmat,1);
@@ -461,26 +465,36 @@ else
 end
 
 if pprior
-    aname='prior_stab';
-    auname='prior_unacceptable';
-    aunstname='prior_unstable';
-    aindname='prior_indeterm';
-    awrongname='prior_wrong';
-    asname='prior_stable';
+    % univariate
+    aname='prior_stab'; atitle='Prior StabMap: Parameter driving non-existence of unique stable solution (Unacceptable)';
+    aindetname=[aname, '_indet']; aindettitle='Prior StabMap: Parameter driving indeterminacy';
+    aunstablename=[aname, '_unst'];  aunstabletitle='Prior StabMap: Parameter driving explosiveness of solution';
+    awronguniname=[aname, '_wrong']; awrongunititle='Prior StabMap: Parameter driving inability to find solution';
+    % bivariate
+    auname='prior_unacceptable'; autitle='Prior StabMap: non-existence of unique stable solution (Unacceptable)';
+    aunstname='prior_unstable'; aunsttitle='Prior StabMap: explosiveness of solution';
+    aindname='prior_indeterm'; aindtitle='Prior StabMap: Indeterminacy';
+    awrongname='prior_wrong'; awrongtitle='Prior StabMap: inability to find solution';
+    asname='prior_stable'; astitle='Prior StabMap: unique Stable Saddle-Path';
 else
-    aname='mc_stab';
-    auname='mc_unacceptable';
-    aunstname='mc_unstable';
-    aindname='mc_indeterm';
-    awrongname='mc_wrong';
-    asname='mc_stable';
+    % univariate
+    aname='mc_stab'; atitle='MC (around posterior mode) StabMap: Parameter driving non-existence of unique stable solution (Unacceptable)';
+    aindetname=[aname, '_indet']; aindettitle='MC (around posterior mode) StabMap: Parameter driving indeterminacy';
+    aunstablename=[aname, '_unst'];  aunstabletitle='MC (around posterior mode) StabMap: Parameter driving explosiveness of solution';
+    awronguniname=[aname, '_wrong']; awrongunititle='MC (around posterior mode) StabMap: Parameter driving inability to find solution';
+    % bivariate
+    auname='mc_unacceptable'; autitle='MC (around posterior mode) StabMap: non-existence of unique stable solution (Unacceptable)';
+    aunstname='mc_unstable'; aunsttitle='MC (around posterior mode) StabMap: explosiveness of solution';
+    aindname='mc_indeterm';  aindtitle='MC (around posterior mode) StabMap: Indeterminacy';
+    awrongname='mc_wrong'; awrongtitle='MC (around posterior mode) StabMap: inability to find solution';
+    asname='mc_stable'; astitle='MC (around posterior mode) StabMap: Unique Stable Saddle-Path';
 end
-delete([OutputDirectoryName,'/',fname_,'_',aname,'_*.*']);
-%delete([OutputDirectoryName,'/',fname_,'_',aname,'_SA_*.*']);
-delete([OutputDirectoryName,'/',fname_,'_',asname,'_corr_*.*']);
-delete([OutputDirectoryName,'/',fname_,'_',auname,'_corr_*.*']);
-delete([OutputDirectoryName,'/',fname_,'_',aunstname,'_corr_*.*']);
-delete([OutputDirectoryName,'/',fname_,'_',aindname,'_corr_*.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',aname,'_*.*']);
+%delete([OutputDirectoryName,filesep,fname_,'_',aname,'_SA_*.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',asname,'_corr_*.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',auname,'_corr_*.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',aunstname,'_corr_*.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',aindname,'_corr_*.*']);
 
 if length(iunstable)>0 && length(iunstable)<Nsam,
     fprintf(['%4.1f%% of the prior support gives unique saddle-path solution.\n'],length(istable)/Nsam*100)
@@ -489,9 +503,9 @@ if length(iunstable)>0 && length(iunstable)<Nsam,
         fprintf(['%4.1f%% of the prior support gives indeterminacy.'],length(iindeterm)/Nsam*100)
     end
     if ~isempty(iwrong),
-        disp(' ');
+        skipline()
         disp(['For ',num2str(length(iwrong)/Nsam*100,'%1.3f'),'\% of the prior support dynare could not find a solution.'])
-        disp(' ');
+        skipline()
         if any(infox==1),
             disp(['    For ',num2str(length(find(infox==1))/Nsam*100,'%1.3f'),'\% The model doesn''t determine the current variables uniquely.'])
         end
@@ -522,9 +536,12 @@ if length(iunstable)>0 && length(iunstable)<Nsam,
         if any(infox==30),
             disp(['    For ',num2str(length(find(infox==30))/Nsam*100,'%1.3f'),'\% Ergodic variance can''t be computed.'])
         end
+        if any(infox==49),
+            disp(['    For ',num2str(length(find(infox==49))/Nsam*100,'%1.3f'),'\% The model violates one (many) endogenous prior restriction(s).'])
+        end
 
     end
-    disp(' ');
+    skipline()
     % Blanchard Kahn
     [proba, dproba] = stab_map_1(lpmat, istable, iunstable, aname,0);
 %     indstab=find(dproba>ksstat);
@@ -533,71 +550,73 @@ if length(iunstable)>0 && length(iunstable)<Nsam,
     for j=1:length(indstab),
         disp([M_.param_names(estim_params_.param_vals(indstab(j),1),:),'   d-stat = ', num2str(dproba(indstab(j)),'%1.3f'),'   p-value = ', num2str(proba(indstab(j)),'%1.3f')])
     end
-    disp(' ');
+    skipline()
     if ~isempty(indstab)
-        stab_map_1(lpmat, istable, iunstable, aname, 1, indstab, OutputDirectoryName);
+        stab_map_1(lpmat, istable, iunstable, aname, 1, indstab, OutputDirectoryName,[],atitle);
     end
     ixun=iunstable(find(~ismember(iunstable,[iindeterm,iwrong])));
     if ~isempty(iindeterm),
-        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], iindeterm, [aname, '_indet'],0);
+        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], iindeterm, aindetname ,0);
 %         indindet=find(dproba>ksstat);
         indindet=find(proba<pvalue_ks);
         disp('Smirnov statistics in driving indeterminacy')
         for j=1:length(indindet),
             disp([M_.param_names(estim_params_.param_vals(indindet(j),1),:),'   d-stat = ', num2str(dproba(indindet(j)),'%1.3f'),'   p-value = ', num2str(proba(indindet(j)),'%1.3f')])
         end
-        disp(' ');
+        skipline()
         if ~isempty(indindet)
-            stab_map_1(lpmat, [1:Nsam], iindeterm, [aname, '_indet'], 1, indindet, OutputDirectoryName);
+            stab_map_1(lpmat, [1:Nsam], iindeterm, aindetname, 1, indindet, OutputDirectoryName,[],aindettitle);
         end
     end
 
     if ~isempty(ixun),
-        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], ixun, [aname, '_unst'],0);
+        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], ixun, aunstablename,0);
 %         indunst=find(dproba>ksstat);
         indunst=find(proba<pvalue_ks);
         disp('Smirnov statistics in driving instability')
         for j=1:length(indunst),
             disp([M_.param_names(estim_params_.param_vals(indunst(j),1),:),'   d-stat = ', num2str(dproba(indunst(j)),'%1.3f'),'   p-value = ', num2str(proba(indunst(j)),'%1.3f')])
         end
-        disp(' ');
+        skipline()
         if ~isempty(indunst)
-            stab_map_1(lpmat, [1:Nsam], ixun, [aname, '_unst'], 1, indunst, OutputDirectoryName);
+            stab_map_1(lpmat, [1:Nsam], ixun, aunstablename, 1, indunst, OutputDirectoryName,[],aunstabletitle);
         end
     end
 
     if ~isempty(iwrong),
-        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], iwrong, [aname, '_wrong'],0);
+        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], iwrong, awronguniname,0);
 %         indwrong=find(dproba>ksstat);
         indwrong=find(proba<pvalue_ks);
         disp('Smirnov statistics in driving no solution')
         for j=1:length(indwrong),
             disp([M_.param_names(estim_params_.param_vals(indwrong(j),1),:),'   d-stat = ', num2str(dproba(indwrong(j)),'%1.3f'),'   p-value = ', num2str(proba(indwrong(j)),'%1.3f')])
         end
-        disp(' ');
+        skipline()
         if ~isempty(indwrong)
-            stab_map_1(lpmat, [1:Nsam], iwrong, [aname, '_wrong'], 1, indwrong, OutputDirectoryName);
+            stab_map_1(lpmat, [1:Nsam], iwrong, awronguniname, 1, indwrong, OutputDirectoryName,[],awrongunititle);
         end
     end
 
-    disp(' ')
+    skipline()
     disp('Starting bivariate analysis:')
 
     c0=corrcoef(lpmat(istable,:));
     c00=tril(c0,-1);
 
-    stab_map_2(lpmat(istable,:),alpha2, pvalue_corr, asname, OutputDirectoryName,xparam1);
+    if length(istable)>10,
+        stab_map_2(lpmat(istable,:),alpha2, pvalue_corr, asname, OutputDirectoryName,xparam1,astitle);
+    end
     if length(iunstable)>10,
-        stab_map_2(lpmat(iunstable,:),alpha2, pvalue_corr, auname, OutputDirectoryName,xparam1);
+        stab_map_2(lpmat(iunstable,:),alpha2, pvalue_corr, auname, OutputDirectoryName,xparam1,autitle);
     end
     if length(iindeterm)>10,
-        stab_map_2(lpmat(iindeterm,:),alpha2, pvalue_corr, aindname, OutputDirectoryName,xparam1);
+        stab_map_2(lpmat(iindeterm,:),alpha2, pvalue_corr, aindname, OutputDirectoryName,xparam1,aindtitle);
     end
     if length(ixun)>10,
-        stab_map_2(lpmat(ixun,:),alpha2, pvalue_corr, aunstname, OutputDirectoryName,xparam1);
+        stab_map_2(lpmat(ixun,:),alpha2, pvalue_corr, aunstname, OutputDirectoryName,xparam1,aunsttitle);
     end
     if length(iwrong)>10,
-        stab_map_2(lpmat(iwrong,:),alpha2, pvalue_corr, awrongname, OutputDirectoryName,xparam1);
+        stab_map_2(lpmat(iwrong,:),alpha2, pvalue_corr, awrongname, OutputDirectoryName,xparam1,awrongtitle);
     end
 
     x0=0.5.*(bayestopt_.ub(1:nshock)-bayestopt_.lb(1:nshock))+bayestopt_.lb(1:nshock);
