@@ -23,7 +23,7 @@ function [xparam1, hh, gg, fval, igg] = newrat(func0, x, analytic_derivation, ft
 %
 %  varargin = list of parameters for func0
 
-% Copyright (C) 2004-2012 Dynare Team
+% Copyright (C) 2004-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -122,7 +122,7 @@ while norm(gg)>gtol && check==0 && jit<nit
         fval=fval1;
         x0=x01;
     end
-    if (fval0(icount)-fval)<1.e-2*(gg'*(H*gg))/2 && igibbs
+%     if icount==1 || (icount>1 && (fval0(icount-1)-fval0(icount))>1) || ((fval0(icount)-fval)<1.e-2*(gg'*(H*gg))/2 && igibbs),
         if length(find(ig))<nx
             ggx=ggx*0;
             ggx(find(ig))=gg(find(ig));
@@ -139,7 +139,7 @@ while norm(gg)>gtol && check==0 && jit<nit
         nig=[nig ig];
         disp('Sequence of univariate steps!!')
         fval=fvala;
-    end
+%     end
     if (fval0(icount)-fval)<ftol && flagit==0
         disp('Try diagonal Hessian')
         ihh=diag(1./(diag(hhg)));
@@ -214,10 +214,10 @@ while norm(gg)>gtol && check==0 && jit<nit
             end
             if htol0>htol
                 htol=htol0;
-                disp(' ')
+                skipline()
                 disp('Numerical noise in the likelihood')
                 disp('Tolerance has to be relaxed')
-                disp(' ')
+                skipline()
             end
             if ~outer_product_gradient,
                 H = bfgsi1(H,gg-g(:,icount),xparam1-x(:,icount));
@@ -236,7 +236,7 @@ while norm(gg)>gtol && check==0 && jit<nit
                 end
                 H = igg;
             end
-        else
+        elseif analytic_derivation,
             [fvalx,gg,hh]=feval(func0,xparam1,DynareDataset,DynareOptions,Model,EstimatedParameters,BayesInfo,DynareResults);
             hhg=hh;
             H = inv(hh);
@@ -256,16 +256,16 @@ end
 
 save m1.mat x hh g hhg igg fval0 nig
 if ftol>ftol0
-    disp(' ')
+    skipline()
     disp('Numerical noise in the likelihood')
     disp('Tolerance had to be relaxed')
-    disp(' ')
+    skipline()
 end
 
 if jit==nit
-    disp(' ')
+    skipline()
     disp('Maximum number of iterations reached')
-    disp(' ')
+    skipline()
 end
 
 if norm(gg)<=gtol
