@@ -10,7 +10,7 @@ function dirlist = dynareParallelDir(filename,PRCDir,Parallel)
 %  OUTPUTS
 %  o dirlist    []   ...
 %
-% Copyright (C) 2009-2011 Dynare Team
+% Copyright (C) 2009-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -36,7 +36,7 @@ for indPC=1:length(Parallel),
             else
                 ssh_token = '';
             end
-            if exist('OCTAVE_VERSION') % Patch for peculiar behaviour of ssh-ls under Linux.
+            if isoctave % Patch for peculiar behaviour of ssh-ls under Linux.
                 % It is necessary to capture the ls warning message.
                 % To do it under the ssh protocol it is necessary to redirect the ls message in a text file.
                 % The file is 'OctaveStandardOutputMessage.txt' and it is
@@ -56,7 +56,7 @@ for indPC=1:length(Parallel),
             end
         else
 
-            if exist('OCTAVE_VERSION') % Patch for peculiar behaviour of ls under Linux.
+            if isoctave % Patch for peculiar behaviour of ls under Linux.
                 
                 % It is necessary to capture the ls warning message and properly manage the jolly char '*'!
                 [check ax]=system(['ls ' ,filename, ' 2> OctaveStandardOutputMessage.txt']);
@@ -74,7 +74,7 @@ for indPC=1:length(Parallel),
 
         end
     else
-        if exist('OCTAVE_VERSION'),     % Patch for peculiar behaviour of ls under Windows.
+        if isoctave     % Patch for peculiar behaviour of ls under Windows.
             if Parallel(indPC).Local==0,
                 ax0=dir(['\\',Parallel(indPC).ComputerName,'\',Parallel(indPC).RemoteDrive,'$\',Parallel(indPC).RemoteDirectory,'\',PRCDir,'\',filename]);
             else
