@@ -14,7 +14,7 @@ function dynareParallelSendFiles(NamFileInput,PRCDir,Parallel)
 %
 %
 %
-% Copyright (C) 2009-2011 Dynare Team
+% Copyright (C) 2009-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -63,7 +63,7 @@ for indPC=1:length(Parallel),
                 if ~isempty(NamFileInput{jfil,1})
                     if isempty(dynareParallelDir(NamFileInput{jfil,1},PRCDir,Parallel(indPC)))
                         
-                        if exist('OCTAVE_VERSION') % Patch for peculiar behaviour of mkdir under Windows.
+                        if isoctave % Patch for peculiar behaviour of mkdir under Windows.
                             
                             % It is Necessary because Octave is not able to
                             % create two nested directory at the same time.
@@ -89,7 +89,7 @@ for indPC=1:length(Parallel),
                     end
                 end
                 
-                if exist('OCTAVE_VERSION') % Patch for peculiar behaviour copyfile ls under Windows.
+                if isoctave % Patch for peculiar behaviour copyfile ls under Windows.
                     
                     % It is Necessary because Octave is not able to
                     % use the jolly char '*' with copyfile.
