@@ -4,22 +4,22 @@ function [fOutVar,nBlockPerCPU, totCPU] = masterParallel(Parallel,fBlock,nBlock,
 % computing.
 % It is the top-level function called on the master computer when parallelizing a task.
 
-% This function have two main computational startegy for manage the matlab worker (slave process).
+% This function has two main computational strategies for managing the matlab worker (slave process).
 % 0 Simple Close/Open Stategy:
-% In this case the new matlab istances (slave process) are open when
+% In this case the new Matlab instances (slave process) are open when
 % necessary and then closed. This can happen many times during the
 % simulation of a model.
 
 % 1 Always Open Strategy:
 % In this case we have a more sophisticated management of slave processes,
 % which are no longer closed at the end of each job. The slave processes
-% waits for a new job (if exist). If a slave do not receives a new job after a
+% wait for a new job (if it exists). If a slave does not receive a new job after a
 % fixed time it is destroyed. This solution removes the computational
-% time necessary to Open/Close new matlab istances.
+% time necessary to Open/Close new Matlab instances.
 
 % The first (point 0) is the default Strategy
 % i.e.(Parallel_info.leaveSlaveOpen=0). This value can be changed by the
-% user in xxx.mod file or it is changed by the programmer if it necessary to
+% user in xxx.mod file or it is changed by the programmer if it is necessary to
 % reduce the overall computational time. See for example the
 % prior_posterior_statistics.m.
 
@@ -30,7 +30,7 @@ function [fOutVar,nBlockPerCPU, totCPU] = masterParallel(Parallel,fBlock,nBlock,
 %  o fBlock [int]               index number of the first thread
 %                               (between 1 and nBlock)
 %  o nBlock [int]               index number of the last thread
-%  o NamFileInput [cell array]  containins the list of input files to be
+%  o NamFileInput [cell array]  contains the list of input files to be
 %                               copied in the working directory of remote slaves
 %                               2 columns, as many lines as there are files
 %                               - first column contains directory paths
@@ -49,11 +49,11 @@ function [fOutVar,nBlockPerCPU, totCPU] = masterParallel(Parallel,fBlock,nBlock,
 %                              struct per thread
 %  o nBlockPerCPU [int vector] for each CPU used, indicates the number of
 %                              threads run on that CPU
-%  o totCPU [int]              total number of CPU used (can be lower than
-%                              the number of CPU declared in "Parallel", if
+%  o totCPU [int]              total number of CPUs used (can be lower than
+%                              the number of CPUs declared in "Parallel", if
 %                              the number of required threads is lower)
 
-% Copyright (C) 2009-2012 Dynare Team
+% Copyright (C) 2009-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -98,18 +98,25 @@ if nargin>8 && initialize==1
     return
 end
 
+if isfield(Parallel_info,'local_files')
+    if isempty(NamFileInput),
+        NamFileInput=Parallel_info.local_files;
+    else
+        NamFileInput=[NamFileInput;Parallel_info.local_files];
+    end
+end
 
-% Deactivate some 'Parallel/Warning' message in Octave!
-% Comment the line 'warning('off');' in order to view the warning message
+% Deactivate some 'Parallel/Warning' messages in Octave!
+% Comment the line 'warning('off');' in order to view the warning messages
 % in Octave!
 
-if exist('OCTAVE_VERSION'),
+if isoctave
     warning('off');
 end
 
 % check if there are function_handles in the input or global vars when
 % octave is used
-if isHybridMatlabOctave || exist('OCTAVE_VERSION'),
+if isHybridMatlabOctave || isoctave
     fInputNames = fieldnames(fInputVar);
     for j=1:length(fInputNames),
         TargetVar = fInputVar.(fInputNames{j});
@@ -358,7 +365,7 @@ for j=1:totCPU,
                     dynareParallelSendFiles([remoteFile,'.m'],PRCDir,Parallel(indPC));
                     delete([remoteFile,'.m']);
                 else
-                    if ~strcmp(Parallel(indPC).ComputerName,MasterName),  % 0.3 Run on a remote machine!
+                    if ~strcmpi(Parallel(indPC).ComputerName,MasterName),  % 0.3 Run on a remote machine!
                         % Hybrid computing Matlab(Master)-> Octave(Slaves) and Vice Versa!
                         if  regexpi([Parallel(indPC).MatlabOctavePath], 'octave')
                             command1=['psexec \\',Parallel(indPC).ComputerName,' -d -e -u ',Parallel(indPC).UserName,' -p ',Parallel(indPC).Password,' -W ',Parallel(indPC).RemoteDrive,':\',Parallel(indPC).RemoteDirectory,'\',PRCDir,'\ -a ',int2str(Parallel(indPC).CPUnbr(j-nCPU0)), ...
@@ -431,7 +438,7 @@ for j=1:totCPU,
                         dynareParallelSendFiles([remoteFile,'.m'],PRCDir,Parallel(indPC));
                         delete([remoteFile,'.m']);
                     else
-                        if ~strcmp(Parallel(indPC).ComputerName,MasterName), % 1.3 Run on a remote machine.
+                        if ~strcmpi(Parallel(indPC).ComputerName,MasterName), % 1.3 Run on a remote machine.
                             % Hybrid computing Matlab(Master)->Octave(Slaves) and Vice Versa!
                             if  regexpi([Parallel(indPC).MatlabOctavePath], 'octave')
                                 command1=['psexec \\',Parallel(indPC).ComputerName,' -d -e -u ',Parallel(indPC).UserName,' -p ',Parallel(indPC).Password,' -W ',Parallel(indPC).RemoteDrive,':\',Parallel(indPC).RemoteDirectory,'\',PRCDir,'\ -a ',int2str(Parallel(indPC).CPUnbr(j-nCPU0)), ...
@@ -497,7 +504,7 @@ if Strategy==0 || newInstance, % See above.
         pause(1)
     else
         
-        if exist('OCTAVE_VERSION')
+        if isoctave
             % Redirect the standard output to the file 'OctaveStandardOutputMessage.txt'!
             % This file is saved in the Model directory.
             system('ConcurrentCommand1.bat > OctaveStandardOutputMessage.txt');
@@ -516,9 +523,9 @@ global options_
 
 % Create a parallel (local/remote) specialized computational status bars!
 
-if exist('OCTAVE_VERSION') || (options_.console_mode == 1),
+if isoctave || options_.console_mode
     diary off;
-    if exist('OCTAVE_VERSION')
+    if isoctave
         printf('\n');
     else
         fprintf('\n');
@@ -568,10 +575,10 @@ idCPU = NaN(1,totCPU);
 
 % Caption for console mode computing ...
 
-if (options_.console_mode == 1) ||  exist('OCTAVE_VERSION')
+if options_.console_mode ||  isoctave
     
-    if ~exist('OCTAVE_VERSION')
-        if strcmp([Parallel(indPC).MatlabOctavePath], 'octave')
+    if ~isoctave
+        if strcmpi([Parallel(indPC).MatlabOctavePath], 'octave')
             RjInformation='Hybrid Computing Is Active: Remote jobs are computed by Octave!';
             fprintf([RjInformation,'\n\n']);
         end
@@ -600,7 +607,7 @@ if (options_.console_mode == 1) ||  exist('OCTAVE_VERSION')
     fnameTemp(L)='';
     
     Information=['Parallel ' fnameTemp ' Computing ...'];
-    if exist('OCTAVE_VERSION')
+    if isoctave
         if (~ispc || strcmpi('unix',Parallel(indPC).OperatingSystem)) && (Strategy==0)
             printf('\n');
             pause(2);
@@ -653,7 +660,7 @@ while (ForEver)
             end
             pcerdone(j) = prtfrc;
             idCPU(j) = njob;
-            if exist('OCTAVE_VERSION') || (options_.console_mode == 1),
+            if isoctave || options_.console_mode
                 if (~ispc || strcmpi('unix',Parallel(indPC).OperatingSystem))
                     statusString = [statusString, int2str(j), ' %3.f%% done! '];
                 else
@@ -665,7 +672,7 @@ while (ForEver)
             end
         catch % ME
             % To define!
-            if exist('OCTAVE_VERSION') || (options_.console_mode == 1),
+            if isoctave || options_.console_mode
                 if (~ispc || strcmpi('unix',Parallel(indPC).OperatingSystem))
                     statusString = [statusString, int2str(j), ' %3.f%% done! '];
                 else
@@ -674,15 +681,14 @@ while (ForEver)
             end
         end
     end
-    if exist('OCTAVE_VERSION') || (options_.console_mode == 1),
-        if exist('OCTAVE_VERSION')
+    if isoctave || options_.console_mode
+        if isoctave
             printf([statusString,'\r'], 100 .* pcerdone);
         else
             if ~isempty(statusString)
                 fprintf([statusString0,statusString], 100 .* pcerdone);
             end
         end
-        
     else
         for j=1:totCPU,
             try
@@ -698,7 +704,7 @@ while (ForEver)
     % 1. The files .log and .txt are not copied.
     % 2. The comp_status_*.mat files are managed separately.
     
-    if exist('OCTAVE_VERSION'), % to avoid synchronism problems
+    if isoctave % to avoid synchronism problems
         try
             PRCDirSnapshot=dynareParallelGetNewFiles(PRCDir,Parallel(1:totSlaves),PRCDirSnapshot);
         catch
@@ -722,8 +728,8 @@ while (ForEver)
         
         if HoTuttiGliOutput==totCPU,
             mydelete(['comp_status_',fname,'*.mat']);
-            if exist('OCTAVE_VERSION')|| (options_.console_mode == 1),
-                if exist('OCTAVE_VERSION')
+            if isoctave || options_.console_mode
+                if isoctave
                     printf('\n');
                     printf(['End Parallel Session ....','\n\n']);
                 else
