@@ -14,7 +14,7 @@ function rplot(s1)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2001-2009 Dynare Team
+% Copyright (C) 2001-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -58,12 +58,12 @@ if rplottype == 0
     for j = 1:size(y,1)
         t = [t s1(j,:) ' '] ;
     end
-    figure ;
+    hh=dyn_figure(options_,'Name',['Simulated Trajectory']);
     plot(ix(i),y(:,i)) ;
     title (t,'Interpreter','none') ;
     xlabel('Periods') ;
     if size(s1,1) > 1
-        if exist('OCTAVE_VERSION')
+        if isoctave
             legend(s1, 0);
         else
             h = legend(s1,0);
@@ -72,13 +72,13 @@ if rplottype == 0
     end
 elseif rplottype == 1
     for j = 1:size(y,1)
-        figure ;
+        hh=dyn_figure(options_,'Name',['Simulated Trajectory']);
         plot(ix(i),y(j,i)) ;
         title(['Plot of ' s1(j,:)],'Interpreter','none') ;
         xlabel('Periods') ;
     end
 elseif rplottype == 2
-    figure ;
+    hh=dyn_figure(options_,'Name',['Simulated Trajectory']);
     nl = max(1,fix(size(y,1)/4)) ;
     nc = ceil(size(y,1)/nl) ;
     for j = 1:size(y,1)
@@ -92,10 +92,21 @@ elseif rplottype == 2
         axis tight;
     end
 end
+% create subdirectory <fname>/graphs if it doesn't exist
+if ~exist(M_.fname, 'dir')
+    mkdir('.',M_.fname);
+end
+if ~exist([M_.fname filesep 'graphs'])
+    mkdir(M_.fname,'graphs');
+end
+
+dyn_saveas(hh,[M_.fname, filesep, 'graphs', filesep, 'SimulatedTrajectory_' deblank(s1(1,:))],options_)
+
 
 % 02/28/01 MJ replaced bseastr by MATLAB's strmatch
 % 06/19/01 MJ added 'exact' to strmatch calls
 % 06/25/03 MJ correction when options_.smpl ~= 0
+% 03/18/13 JP bugfix for rplottype>0; added figure names
 
 
 
