@@ -12,7 +12,7 @@ function simul()
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 1996-2012 Dynare Team
+% Copyright (C) 1996-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -50,22 +50,22 @@ if (options_.block || options_.bytecode) && options_.stack_solve_algo == 6
     error('SIMUL: you can''t use stack_solve_algo = 6 with block or bytecode option')
 end
 
-if exist('OCTAVE_VERSION') && options_.stack_solve_algo == 2
+if isoctave && options_.stack_solve_algo == 2
     error('SIMUL: you can''t use stack_solve_algo = 2 under Octave')
 end
 
 if size(M_.lead_lag_incidence,2)-nnz(M_.lead_lag_incidence(M_.maximum_endo_lag+1,:)) > 0
-    mess = ['SIMUL: error in model specification : variable ' M_.endo_names(find(M_.lead_lag_incidence(M_.maximum_lag+1,:)==0),:)] ;
-    mess = [mess ' doesn''t appear as current variable.'] ; 
-    error (mess) ;
+    mess = ['SIMUL: error in model specification : variable ' M_.endo_names(find(M_.lead_lag_incidence(M_.maximum_lag+1,:)==0),:)];
+    mess = [mess ' doesn''t appear as current variable.'];
+    error(mess)
 end
 
 if options_.periods == 0
     error('SIMUL: number of periods for the simulation isn''t specified')
 end
 
-if ~ options_.initval_file
-    if ~isfield(options_,'datafile')
+if ~options_.initval_file
+    if isempty(options_.datafile)
         make_ex_;
         make_y_;
     else
@@ -74,10 +74,26 @@ if ~ options_.initval_file
 end
 
 if isempty(options_.scalv) || options_.scalv == 0
-    options_.scalv = oo_.steady_state ;
+    options_.scalv = oo_.steady_state;
 end
 
-options_.scalv= 1 ;
+options_.scalv= 1;
+
+if options_.debug
+    model_static = str2func([M_.fname,'_static']);
+    for ii=1:size(oo_.exo_simul,1)
+        [residual(:,ii)] = model_static(oo_.steady_state, oo_.exo_simul(ii,:),M_.params);
+    end
+    problematic_periods=find(any(isinf(residual)) | any(isnan(residual)))-M_.maximum_endo_lag;
+    if ~isempty(problematic_periods) 
+        period_string=num2str(problematic_periods(1));
+        for ii=2:length(problematic_periods)
+            period_string=[period_string, ', ', num2str(problematic_periods(ii))];
+        end
+        fprintf('\n\nWARNING: Value for the exogenous variable(s) in period(s) %s inconsistent with the static model.\n',period_string);   
+        fprintf('WARNING: Check for division by 0.\n')
+    end
+end
 
 if(options_.block)
     if(options_.bytecode)
@@ -86,14 +102,19 @@ if(options_.block)
             oo_.deterministic_simulation.status = 0;
         else
             oo_.deterministic_simulation.status = 1;
-        end;
+        end
         mexErrCheck('bytecode', info);
     else
         eval([M_.fname '_dynamic']);
-    end;
+    end
 else
     if(options_.bytecode)
         [info, oo_.endo_simul]=bytecode('dynamic');
+        if info == 1
+            oo_.deterministic_simulation.status = 0;
+        else
+            oo_.deterministic_simulation.status = 1;
+        end;
         mexErrCheck('bytecode', info);
     else
         if M_.maximum_endo_lead == 0 % Purely backward model
@@ -107,7 +128,7 @@ else
                 sim1_lbj;
             end
         end
-    end;
-end;
+    end
+end
 
 dyn2vec;
\ No newline at end of file
