@@ -21,7 +21,7 @@ function [dr,info] = stochastic_solvers(dr,task,M_,options_,oo_)
 %                                         indeterminacy.
 %                                 info=5: BK rank condition not satisfied.
 %                                 info=6: The jacobian matrix evaluated at the steady state is complex.        
-%  
+%                                 info=9: k_order_pert was unable to compute the solution    
 % ALGORITHM
 %   ...
 %    
@@ -29,7 +29,7 @@ function [dr,info] = stochastic_solvers(dr,task,M_,options_,oo_)
 %   none.
 %  
 
-% Copyright (C) 1996-2012 Dynare Team
+% Copyright (C) 1996-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -56,13 +56,22 @@ if (options_.aim_solver == 1) && (options_.order > 1)
         error('Option "aim_solver" is incompatible with order >= 2')
 end
 
+
+if M_.maximum_endo_lag == 0 && options_.order >= 2
+    fprintf('\nSTOCHASTIC_SOLVER: Dynare does not solve purely forward models at higher order.\n')
+    fprintf('STOCHASTIC_SOLVER: To circumvent this restriction, you can add a backward-looking dummy equation of the form:\n')
+    fprintf('STOCHASTIC_SOLVER: junk=0.9*junk(-1);\n')
+    error(['2nd and 3rd order approximation not implemented for purely ' ...
+           'forward models'])
+end
+
 if options_.k_order_solver;
     if options_.risky_steadystate
         [dr,info] = dyn_risky_steadystate_solver(oo_.steady_state,M_,dr, ...
                                              options_,oo_);
     else
-        dr = set_state_space(dr,M_);
-        [dr,info] = k_order_pert(dr,M_,options_,oo_);
+        dr = set_state_space(dr,M_,options_);
+        [dr,info] = k_order_pert(dr,M_,options_);
     end
     return;
 end
@@ -106,10 +115,38 @@ elseif options_.order == 2
     end
 end
 
+[infrow,infcol]=find(isinf(jacobia_));
+    
 if options_.debug
+    if ~isempty(infrow)     
+        for ii=1:length(infrow)
+            [var_row,var_index]=find(M_.lead_lag_incidence==infcol(ii));
+            if var_row==2
+                type_string='';
+            elseif var_row==1
+                type_string='lag of';
+            elseif var_row==3;
+                type_string='lead of';
+            end
+            if var_index<=M_.orig_endo_nbr
+                fprintf('STOCHASTIC_SOLVER:  Derivative of Equation %d with respect to %s Variable %s  (initial value of %s: %g) \n',infrow(ii),type_string,deblank(M_.endo_names(var_index,:)),deblank(M_.endo_names(var_index,:)),dr.ys(var_index))
+            else %auxiliary vars
+                orig_var_index=M.aux_vars(1,var_index-M_.orig_endo_nbr).orig_index;
+                fprintf('STOCHASTIC_SOLVER:  Derivative of Equation %d with respect to %s Variable %s  (initial value of %s: %g) \n',infrow(ii),type_string,deblank(M_.endo_names(orig_var_index,:)),deblank(M_.endo_names(orig_var_index,:)),dr.ys(orig_var_index))            
+            end    
+        end
+        fprintf('\nSTOCHASTIC_SOLVER:  The problem most often occurs, because a variable with\n')
+        fprintf('STOCHASTIC_SOLVER:  exponent smaller than 1 has been initialized to 0. Taking the derivative\n')
+        fprintf('STOCHASTIC_SOLVER:  and evaluating it at the steady state then results in a division by 0.\n')
+    end
     save([M_.fname '_debug.mat'],'jacobia_')
 end
 
+if ~isempty(infrow)
+    info(1)=10;
+    return
+end
+
 if ~isreal(jacobia_)
     if max(max(abs(imag(jacobia_)))) < 1e-15
         jacobia_ = real(jacobia_);
@@ -120,14 +157,19 @@ if ~isreal(jacobia_)
     end
 end
 
+if any(any(isnan(jacobia_)))
+   info(1) = 8;
+   NaN_params=find(isnan(M_.params));
+   info(2:length(NaN_params)+1) =  NaN_params;
+   return
+end
+
 kstate = dr.kstate;
-kad = dr.kad;
-kae = dr.kae;
-nstatic = dr.nstatic;
-nfwrd = dr.nfwrd;
-npred = dr.npred;
-nboth = dr.nboth;
-nfwrds = nfwrd+nboth;
+nstatic = M_.nstatic;
+nfwrd = M_.nfwrd;
+nspred = M_.nspred;
+nboth = M_.nboth;
+nsfwrd = M_.nsfwrd;
 order_var = dr.order_var;
 nd = size(kstate,1);
 nz = nnz(M_.lead_lag_incidence);
@@ -157,6 +199,9 @@ if M_.maximum_endo_lead == 0
             info(2) = temp'*temp;
         end
     else
+        fprintf('\nSTOCHASTIC_SOLVER: Dynare does not solve purely backward models at higher order.\n')
+        fprintf('STOCHASTIC_SOLVER: To circumvent this restriction, you can add a forward-looking dummy equation of the form:\n')
+        fprintf('STOCHASTIC_SOLVER: junk=0.9*junk(+1);\n')
         error(['2nd and 3rd order approximation not implemented for purely ' ...
                'backward models'])
     end
@@ -189,34 +234,34 @@ if M_.exo_det_nbr > 0
     f1 = sparse(jacobia_(:,nonzeros(M_.lead_lag_incidence(M_.maximum_endo_lag+2:end,order_var))));
     f0 = sparse(jacobia_(:,nonzeros(M_.lead_lag_incidence(M_.maximum_endo_lag+1,order_var))));
     fudet = sparse(jacobia_(:,nz+M_.exo_nbr+1:end));
-    M1 = inv(f0+[zeros(M_.endo_nbr,nstatic) f1*gx zeros(M_.endo_nbr,nfwrds-nboth)]);
+    M1 = inv(f0+[zeros(M_.endo_nbr,nstatic) f1*gx zeros(M_.endo_nbr,nsfwrd-nboth)]);
     M2 = M1*f1;
     dr.ghud = cell(M_.exo_det_length,1);
     dr.ghud{1} = -M1*fudet;
     for i = 2:M_.exo_det_length
-        dr.ghud{i} = -M2*dr.ghud{i-1}(end-nfwrds+1:end,:);
+        dr.ghud{i} = -M2*dr.ghud{i-1}(end-nsfwrd+1:end,:);
     end
 
     if options_.order > 1
         lead_lag_incidence = M_.lead_lag_incidence;
         k0 = find(lead_lag_incidence(M_.maximum_endo_lag+1,order_var)');
         k1 = find(lead_lag_incidence(M_.maximum_endo_lag+2,order_var)');
-        hu = dr.ghu(nstatic+[1:npred],:);
-        hud = dr.ghud{1}(nstatic+1:nstatic+npred,:);
-        zx = [eye(npred);dr.ghx(k0,:);gx*dr.Gy;zeros(M_.exo_nbr+M_.exo_det_nbr, ...
-                                               npred)];
-        zu = [zeros(npred,M_.exo_nbr); dr.ghu(k0,:); gx*hu; zeros(M_.exo_nbr+M_.exo_det_nbr, ...
+        hu = dr.ghu(nstatic+[1:nspred],:);
+        hud = dr.ghud{1}(nstatic+1:nstatic+nspred,:);
+        zx = [eye(nspred);dr.ghx(k0,:);gx*dr.Gy;zeros(M_.exo_nbr+M_.exo_det_nbr, ...
+                                               nspred)];
+        zu = [zeros(nspred,M_.exo_nbr); dr.ghu(k0,:); gx*hu; zeros(M_.exo_nbr+M_.exo_det_nbr, ...
                                                           M_.exo_nbr)];
-        zud=[zeros(npred,M_.exo_det_nbr);dr.ghud{1};gx(:,1:npred)*hud;zeros(M_.exo_nbr,M_.exo_det_nbr);eye(M_.exo_det_nbr)];
+        zud=[zeros(nspred,M_.exo_det_nbr);dr.ghud{1};gx(:,1:nspred)*hud;zeros(M_.exo_nbr,M_.exo_det_nbr);eye(M_.exo_det_nbr)];
         R1 = hessian1*kron(zx,zud);
         dr.ghxud = cell(M_.exo_det_length,1);
         kf = [M_.endo_nbr-nfwrd-nboth+1:M_.endo_nbr];
-        kp = nstatic+[1:npred];
+        kp = nstatic+[1:nspred];
         dr.ghxud{1} = -M1*(R1+f1*dr.ghxx(kf,:)*kron(dr.ghx(kp,:),dr.ghud{1}(kp,:)));
         Eud = eye(M_.exo_det_nbr);
         for i = 2:M_.exo_det_length
             hudi = dr.ghud{i}(kp,:);
-            zudi=[zeros(npred,M_.exo_det_nbr);dr.ghud{i};gx(:,1:npred)*hudi;zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
+            zudi=[zeros(nspred,M_.exo_det_nbr);dr.ghud{i};gx(:,1:nspred)*hudi;zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
             R2 = hessian1*kron(zx,zudi);
             dr.ghxud{i} = -M2*(dr.ghxud{i-1}(kf,:)*kron(dr.Gy,Eud)+dr.ghxx(kf,:)*kron(dr.ghx(kp,:),dr.ghud{i}(kp,:)))-M1*R2;
         end
@@ -226,7 +271,7 @@ if M_.exo_det_nbr > 0
         Eud = eye(M_.exo_det_nbr);
         for i = 2:M_.exo_det_length
             hudi = dr.ghud{i}(kp,:);
-            zudi=[zeros(npred,M_.exo_det_nbr);dr.ghud{i};gx(:,1:npred)*hudi;zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
+            zudi=[zeros(nspred,M_.exo_det_nbr);dr.ghud{i};gx(:,1:nspred)*hudi;zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
             R2 = hessian1*kron(zu,zudi);
             dr.ghuud{i} = -M2*dr.ghxud{i-1}(kf,:)*kron(hu,Eud)-M1*R2;
         end
@@ -234,8 +279,8 @@ if M_.exo_det_nbr > 0
         dr.ghudud = cell(M_.exo_det_length,M_.exo_det_length);
         dr.ghudud{1,1} = -M1*R1-M2*dr.ghxx(kf,:)*kron(hud,hud);
         for i = 2:M_.exo_det_length
-            hudi = dr.ghud{i}(nstatic+1:nstatic+npred,:);
-            zudi=[zeros(npred,M_.exo_det_nbr);dr.ghud{i};gx(:,1:npred)*hudi+dr.ghud{i-1}(kf,:);zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
+            hudi = dr.ghud{i}(nstatic+1:nstatic+nspred,:);
+            zudi=[zeros(nspred,M_.exo_det_nbr);dr.ghud{i};gx(:,1:nspred)*hudi+dr.ghud{i-1}(kf,:);zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
             R2 = hessian1*kron(zudi,zudi);
             dr.ghudud{i,i} = -M2*(dr.ghudud{i-1,i-1}(kf,:)+...
                                   2*dr.ghxud{i-1}(kf,:)*kron(hudi,Eud) ...
@@ -246,7 +291,7 @@ if M_.exo_det_nbr > 0
                 -M1*R2;
             for j=2:i-1
                 hudj = dr.ghud{j}(kp,:);
-                zudj=[zeros(npred,M_.exo_det_nbr);dr.ghud{j};gx(:,1:npred)*hudj;zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
+                zudj=[zeros(nspred,M_.exo_det_nbr);dr.ghud{j};gx(:,1:nspred)*hudj;zeros(M_.exo_nbr+M_.exo_det_nbr,M_.exo_det_nbr)];
                 R2 = hessian1*kron(zudj,zudi);
                 dr.ghudud{j,i} = -M2*(dr.ghudud{j-1,i-1}(kf,:)+dr.ghxud{j-1}(kf,:)* ...
                                       kron(hudi,Eud)+dr.ghxud{i-1}(kf,:)* ...
@@ -266,5 +311,8 @@ if options_.loglinear == 1
     dr.ghx = repmat(1./dr.ys(k1),1,size(dr.ghx,2)).*dr.ghx.* ...
              repmat(dr.ys(k1(klag(:,1)))',size(dr.ghx,1),1);
     dr.ghu = repmat(1./dr.ys(k1),1,size(dr.ghu,2)).*dr.ghu;
+    if options_.order>1
+       error('Loglinear options currently only works at order 1') 
+    end
 end
 
