@@ -1,7 +1,7 @@
 function dataset_ = initialize_dataset(datafile,varobs,first,nobs,transformation,prefilter,xls)
 % Initializes a structure describing the dataset.
 
-% Copyright (C) 2011 Dynare Team
+% Copyright (C) 2011-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -32,7 +32,7 @@ end
 rawdata = read_variables(datafile,varobs,[],xls.sheet,xls.range);
 
 % Get the (default) number of observations.
-if isempty(nobs)
+if isempty(nobs) || rows(rawdata)<nobs+first-1 %case 2: dataset has changed
     nobs = rows(rawdata)-first+1;
 end
 
@@ -48,14 +48,17 @@ dataset_.info.varobs = varobs;
 
 % Test the number of variables in the database.
 if dataset_.info.nvobs-size(rawdata,2)
-    disp(' ')
+    skipline()
     disp(['Declared number of observed variables = ' int2str(dataset.info.nvobs)])
     disp(['Number of variables in the database   = ' int2str(size(rawdata,2))])
-    disp(' ')
+    skipline()
     error(['Estimation can''t take place because the declared number of observed' ...
            'variables doesn''t match the number of variables in the database.'])
 end
 
+if size(rawdata,1)~=dataset_.info.ntobs
+   fprintf('Restricting the sample to observations %d to %d. Using in total %d observations. \n',first,first+dataset_.info.ntobs-1,dataset_.info.ntobs)
+end
 rawdata = rawdata(first:(first+dataset_.info.ntobs-1),:);
 
 % Take the log (or anything else) of the variables if needed
