@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2012 Dynare Team
+ * Copyright (C) 2010-2013 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -516,16 +516,32 @@ ConfigFile::checkPass(WarningConsolidation &warnings) const
               cerr << "ERROR (node " << it->first << "): the UserName option must be passed for every remote node." << endl;
               exit(EXIT_FAILURE);
             }
-#if defined(_WIN32) || defined(__CYGWIN32__)
-          if (it->second->userName.empty() || it->second->password.empty())
+          if (it->second->operatingSystem.compare("windows") == 0)
             {
-              cerr << "ERROR (node " << it->first << "): the Password option must be passed under Windows for every remote node." << endl;
-              exit(EXIT_FAILURE);
+              if (it->second->password.empty())
+                {
+                  cerr << "ERROR (node " << it->first << "): the Password option must be passed under Windows for every remote node." << endl;
+                  exit(EXIT_FAILURE);
+                }
+              if (it->second->remoteDrive.empty())
+                {
+                  cerr << "ERROR (node " << it->first << "): the RemoteDrive option must be passed under Windows for every remote node." << endl;
+                  exit(EXIT_FAILURE);
+                }
             }
-          if (it->second->remoteDrive.empty())
+#if defined(_WIN32) || defined(__CYGWIN32__)
+          if (it->second->operatingSystem.empty())
             {
-              cerr << "ERROR (node " << it->first << "): the RemoteDrive option must be passed under Windows for every remote node." << endl;
-              exit(EXIT_FAILURE);
+              if (it->second->password.empty())
+                {
+                  cerr << "ERROR (node " << it->first << "): the Password option must be passed under Windows for every remote node." << endl;
+                  exit(EXIT_FAILURE);
+                }
+              if (it->second->remoteDrive.empty())
+                {
+                  cerr << "ERROR (node " << it->first << "): the RemoteDrive option must be passed under Windows for every remote node." << endl;
+                  exit(EXIT_FAILURE);
+                }
             }
 #endif
           if (it->second->remoteDirectory.empty())
