@@ -1,6 +1,6 @@
 function run_ls2003(block, bytecode, solve_algo, stack_solve_algo)
 
-% Copyright (C) 2010-2011 Dynare Team
+% Copyright (C) 2010-2013 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -17,6 +17,11 @@ function run_ls2003(block, bytecode, solve_algo, stack_solve_algo)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
+  % Workaround for a strange race condition under Octave
+  if exist('ls2003_tmp.m') == 2
+      delete('ls2003_tmp.m')
+  end
+
   disp(['TEST: ls2003 (block=' num2str(block) ', bytecode=' ...
       num2str(bytecode) ', solve_algo=' num2str(solve_algo) ...
       ', stack_solve_algo=' num2str(stack_solve_algo) ')...']);
